@@ -9,6 +9,7 @@
 import click
 
 from basecam.actor.tools import get_cameras
+
 from . import camera_parser
 
 
@@ -29,22 +30,24 @@ async def status(command, cameras):
         for camera in cameras:
             try:
                 status[camera.name] = camera.get_status(update=True)
-            except Exception as ex:
+            except Exception:
                 pass
 
             try:
                 status[camera.name]["binning"] = list(await camera.get_binning())
-            except Exception as ex:
+            except Exception:
                 pass
 
             try:
                 status[camera.name]["area"] = tuple(await camera.get_image_area())
-            except Exception as ex:
+            except Exception:
                 pass
 
             try:
-                status[camera.name]["state"] = "online" if camera.connected else "offline"
-            except Exception as ex:
+                status[camera.name]["state"] = (
+                    "online" if camera.connected else "offline"
+                )
+            except Exception:
                 pass
 
         return command.finish(status)
